pub struct ShiftRegister<SPI, OE, CLR, LATCH, D> { /* private fields */ }Expand description
A 74hc595 (compatible) shift register.
Implementations
Sourceimpl<SPI, OE, CLR, LATCH, D> ShiftRegister<SPI, OE, CLR, LATCH, D>
impl<SPI, OE, CLR, LATCH, D> ShiftRegister<SPI, OE, CLR, LATCH, D>
Sourcepub fn new(spi: SPI, not_oe: OE, not_clr: CLR, latch: LATCH, delay: D) -> Self
pub fn new(spi: SPI, not_oe: OE, not_clr: CLR, latch: LATCH, delay: D) -> Self
Creates a new ShiftRegister.
Sourcepub fn output_enable(&mut self, enable: bool) -> Result<(), OE::Error>
pub fn output_enable(&mut self, enable: bool) -> Result<(), OE::Error>
Enables or disables the shift register output drivers.
Sourcepub async fn clear(&mut self) -> Result<(), CLR::Error>
pub async fn clear(&mut self) -> Result<(), CLR::Error>
Clears the shift register.
This does not change the value of the output latches. Use Self::latch()
after clearing if you want the outputs to be reset.
Sourcepub async fn latch(&mut self) -> Result<(), LATCH::Error>
pub async fn latch(&mut self) -> Result<(), LATCH::Error>
Latches the current values in the shift register into the output latches.